@@ -48,6 +48,10 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
         creds['region_name'] = conf['region_name']
       end
 
+      if conf['interface']
+        creds['interface'] = conf['interface']
+      end
+
       return creds
     else
       raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
@@ -212,14 +216,9 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
 
   def self.fetch_user(name, domain)
     domain ||= default_domain
-    user = request('user', 'show',
-                   [name, '--domain', domain],
-                   {:no_retry_exception_msgs => /No user with a name or ID/})
-    # The description key is only set if it exists
-    if user and user.key?(:id) and !user.key?(:description)
-        user[:description] = ''
-    end
-    user
+    request('user', 'show',
+            [name, '--domain', domain],
+            {:no_retry_exception_msgs => /No user with a name or ID/})
   rescue Puppet::ExecutionFailure => e
     raise e unless e.message =~ /No user with a name or ID/
   end
