@@ -32,8 +32,6 @@ describe 'keystone' do
 
       it 'should set the default values' do
         is_expected.to contain_resources('keystone_config').with({ :purge => false })
-        is_expected.to contain_keystone_config('DEFAULT/member_role_id').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('DEFAULT/member_role_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/expiration').with_value(3600)
         is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value('<SERVICE DEFAULT>')
@@ -101,14 +99,27 @@ describe 'keystone' do
       it { is_expected.to contain_exec('keystone-manage db_sync') }
 
       it { is_expected.to_not contain_file('/etc/keystone/domains') }
+
+      it { is_expected.to contain_file('/etc/keystone/credential-keys').with(
+        :ensure => 'directory',
+        :owner  => 'keystone',
+        :group  => 'keystone',
+        'mode'  => '0600',
+      ) }
+
+      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
+        :command => 'keystone-manage credential_setup --keystone-user keystone --keystone-group keystone',
+        :user    => 'keystone',
+        :creates => '/etc/keystone/credential-keys/0',
+        :require => 'File[/etc/keystone/credential-keys]',
+      ) }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys')}
     end
 
     context 'with overridden parameters' do
       let :params do
         {
           :purge_config                 => true,
-          :member_role_id               => 'someid',
-          :member_role_name             => 'member',
           :public_endpoint              => 'http://127.0.0.1:5000',
           :token_expiration             => 7200,
           :password_hash_algorithm      => 'bcrypt',
@@ -128,8 +139,6 @@ describe 'keystone' do
 
       it 'should set the overridden values' do
         is_expected.to contain_resources('keystone_config').with({ :purge => true })
-        is_expected.to contain_keystone_config('DEFAULT/member_role_id').with_value('someid')
-        is_expected.to contain_keystone_config('DEFAULT/member_role_name').with_value('member')
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
         is_expected.to contain_keystone_config('token/expiration').with_value(7200)
         is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value('bcrypt')
@@ -309,28 +318,16 @@ describe 'keystone' do
       ) }
     end
 
-    context 'when enabling credential_setup' do
+    context 'when disabling credential_setup' do
       let :params do
         {
-          'enable_credential_setup'   => true,
-          'credential_key_repository' => '/etc/keystone/credential-keys',
+          'enable_credential_setup' => false,
         }
       end
 
-      it { is_expected.to contain_file(params['credential_key_repository']).with(
-        :ensure => 'directory',
-        :owner  => 'keystone',
-        :group  => 'keystone',
-        'mode'  => '0600',
-      ) }
-
-      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
-        :command => 'keystone-manage credential_setup --keystone-user keystone --keystone-group keystone',
-        :user    => 'keystone',
-        :creates => '/etc/keystone/credential-keys/0',
-        :require => 'File[/etc/keystone/credential-keys]',
-      ) }
-      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys')}
+      it { is_expected.to_not contain_file('/etc/keystone/credential-keys') }
+      it { is_expected.to_not contain_exec('keystone-manage credential_setup') }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys') }
     end
 
     context 'when overriding the credential key directory' do
@@ -341,9 +338,16 @@ describe 'keystone' do
         }
       end
 
+      it { is_expected.to contain_file('/var/lib/credential-keys').with(
+        :ensure => 'directory',
+        :owner  => 'keystone',
+        :group  => 'keystone',
+        'mode'  => '0600',
+      ) }
       it { is_expected.to contain_exec('keystone-manage credential_setup').with(
         :creates => '/var/lib/credential-keys/0'
       ) }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/var/lib/credential-keys') }
     end
 
     context 'when overriding the keystone group and user' do
